@@ -1,30 +1,11 @@
-/*==========================================================================
- =                                                                         =
- =                        Project CTI-Print                                =
- =                                                                         =
- = Author:                                                                 =
- =   Panos Dimakopoulos, Systems Programmer,                               =
- =   Computer Technology Institute,                                        =
- =   Division of Computing Facilities,                                     =
- =   P.O. Box 1122,                                                        =
- =   261 10  Patras,                                                       =
- =   Greece                                                                =
- =   (e-mail: dimakop@cti.gr)                                              =
- =   Tel: +30 61 992061                                                    =
- =   Fax: +30 61 993973                                                    =
- =                                                                         =
- = Created by Patrick Powell  <papowell@sdsu.edu>                          =
- =   for LPRng software Sat Aug 26 06:54:25 PDT 1995                       =
- ==========================================================================*/
-
-
-/*==========================================================================
-  Version CTI-LPRng-1.0
-  =========================================================================*/
-
-
-/*
- * $Id: stty.c,v 1.3 1996/04/21 19:14:34 papowell Exp $
+/**************************************************************************
+ * LPRng IFHP Filter
+ * Copyright 1994-1997 Patrick Powell, San Diego, CA <papowell@sdsu.edu>
+ *
+ * Based on the CTI printer filters.
+ *  See COPYRIGHT for details.
+ *
+ * $Id: stty.c,v 2.1 1997/01/05 18:41:46 papowell Exp $
  */
 
 #include "portable.h"
